@@ -1,4 +1,6 @@
 from pkgutil import extend_path
 __path__ = extend_path(__path__, __name__)
 
+from .backends import *
 from .template_tags import *
+from .with_section import *
